pub struct CheckPlan {Show 14 fields
pub base: String,
pub head: String,
pub scope: Scope,
pub diff_context: u32,
pub fail_on: FailOn,
pub max_findings: usize,
pub path_filters: Vec<String>,
pub only_tags: Vec<String>,
pub enable_tags: Vec<String>,
pub disable_tags: Vec<String>,
pub directory_overrides: Vec<DirectoryRuleOverride>,
pub force_language: Option<String>,
pub allowed_lines: Option<BTreeSet<(String, u32)>>,
pub false_positive_fingerprints: BTreeSet<String>,
}Fields
base: Stringhead: Stringscope: Scopediff_context: u32fail_on: FailOnmax_findings: usizepath_filters: Vec<String>Only include rules that have at least one of these tags. Empty means no filtering by this criterion.
Include rules that have at least one of these tags (additive). Empty means no filtering by this criterion.
Exclude rules that have any of these tags. Empty means no filtering by this criterion.
directory_overrides: Vec<DirectoryRuleOverride>Per-directory rule overrides loaded from .diffguard.toml files.
force_language: Option<String>Force all files to be treated as this language for preprocessing/rule filtering.
allowed_lines: Option<BTreeSet<(String, u32)>>Optional line-level allowlist (path, line) for secondary filtering.
When set, only these diff lines are evaluated.
false_positive_fingerprints: BTreeSet<String>Finding fingerprints to treat as acknowledged false positives.